@@ -12,9 +12,10 @@ import subprocess
 import sys
 import tempfile
 
+from collections import OrderedDict
 from os import path
 
-VERSION = '0.4.0'
+VERSION = '0.4.1'
 
 class Dotlink(object):
     """Copy or symlink dotfiles from a profile repository to a new location,
@@ -25,6 +26,8 @@ class Dotlink(object):
     @staticmethod
     def parse_args():
         parser = argparse.ArgumentParser(description=Dotlink.__doc__)
+        parser.add_argument('-V', '--version', action='version',
+                            version='dotlink v%s' % VERSION)
         parser.add_argument('-d', '--debug', action='store_true', default=False,
                             help='enable debug output')
         parser.add_argument('-c', '--copy', action='store_true', default=False,
@@ -132,7 +135,7 @@ class Dotlink(object):
             source = path.dirname(map_path)
 
         if dotfiles is None:
-            dotfiles = {}
+            dotfiles = OrderedDict()
 
         lineno = 0
 
